@@ -8,9 +8,9 @@ from weakref import WeakValueDictionary
 
 from snakeoil import klass
 from snakeoil.demandload import demand_compile_regexp
+from snakeoil.mappings import ImmutableDict, OrderedFrozenSet, inject_getitem_as_getattr
 from snakeoil.osutils import pjoin
 from snakeoil.process.spawn import bash_version
-from snakeoil.mappings import ImmutableDict, OrderedFrozenSet, inject_getitem_as_getattr
 
 from ..log import logger
 from . import atom, const
@@ -19,8 +19,10 @@ demand_compile_regexp(
     '_valid_EAPI_regex', r"^[A-Za-z0-9_][A-Za-z0-9+_.-]*$"
 )
 
-
 eapi_optionals = ImmutableDict({
+    # Controls whether PROPERTIES and RESTRICT are accumulated across eclasses.
+    "accumulate_properties_restrict": False,
+
     # Controls what version of bash compatibility to force; see PMS.
     "bash_compat": '3.2',
 
@@ -33,6 +35,9 @@ eapi_optionals = ImmutableDict({
     # Controls whether -i18n option is allowed.
     "doman_language_override": False,
 
+    # Controls whether dosym -r option is allowed.
+    "dosym_relative": False,
+
     # Controls whether an ebuild_phase function exists for ebuild consumption.
     'ebuild_phase_func': False,
 
@@ -124,6 +129,9 @@ eapi_optionals = ImmutableDict({
     # Controls whether SRC_URI supports the '->' operator for url filename renaming.
     "src_uri_renames": False,
 
+    # Controls whether SRC_URI supports fetch+ and mirror+ prefixes.
+    "src_uri_unrestrict": False,
+
     # Controls whether or not use dependency atoms are able to control their enforced
     # value relative to another; standard use deps just enforce either on or off; EAPIs
     # supporting this allow syntax that can enforce (for example) X to be on if Y is on.
@@ -142,6 +150,9 @@ eapi_optionals = ImmutableDict({
     # Controls whether unpack supports absolute paths; see PMS.
     "unpack_case_insensitive": False,
 
+    # Regular expression to filter out valid update files
+    "update_regex": re.compile(r'^([1-4])Q-(\d{4})$'),
+
     # Controls whether user patches are supported.
     "user_patches": False,
 })
@@ -512,7 +523,7 @@ common_archive_exts = (
 common_env_optionals = (
     "bash_compat", "ebuild_phase_func", "global_failglob",
     "new_reads_stdin", "nonfatal", "nonfatal_die",
-    "has_desttree",
+    "has_desttree", "accumulate_properties_restrict",
 )
 
 eapi0 = EAPI.register(
@@ -679,3 +690,28 @@ eapi7 = EAPI.register(
     )),
     ebd_env_options=eapi6._ebd_env_options,
 )
+
+eapi8 = EAPI.register(
+    magic="8",
+    parent=eapi7,
+    phases=eapi7.phases,
+    default_phases=eapi7.default_phases,
+    mandatory_keys=eapi7.mandatory_keys,
+    dep_keys=eapi7.dep_keys | frozenset(["IDEPEND"]),
+    metadata_keys=eapi7.metadata_keys,
+    eclass_keys=eapi7.eclass_keys,
+    tracked_attributes=eapi7.tracked_attributes,
+    archive_exts=eapi7.archive_exts - frozenset([
+        ".rar", ".RAR",
+        ".lha", ".LHa", ".LHA", ".lzh",
+        ".7z", ".7Z",
+    ]),
+    optionals=_combine_dicts(eapi7.options, dict(
+        accumulate_properties_restrict=True,
+        bash_compat='5.0',
+        dosym_relative=True,
+        src_uri_unrestrict=True,
+        update_regex=re.compile(r'^[^.]'),
+    )),
+    ebd_env_options=eapi7._ebd_env_options,
+)
