@@ -10,22 +10,19 @@ __all__ = (
 import fnmatch
 import os
 
-from snakeoil import compatibility
 from snakeoil.bash import read_bash_dict
 from snakeoil.fileutils import AtomicWriteFile
-from snakeoil.osutils import listdir_files, abspath, normpath, pjoin
-from snakeoil.sequences import stable_unique, iflatten_instance
-
-from pkgcore import os_data, ospkg
-from pkgcore.fs import livefs
-from pkgcore.log import logger
-from pkgcore.merge import triggers, const, errors
-from pkgcore.restrictions import values
-from pkgcore.system import libtool
+from snakeoil.osutils import listdir_files, normpath, pjoin
+from snakeoil.sequences import iflatten_instance, stable_unique
 
+from .. import os_data
+from ..fs import livefs
+from ..merge import const, errors, triggers
+from ..restrictions import values
+from ..system import libtool
 
 colon_parsed = frozenset([
-    "ADA_INCLUDE_PATH",  "ADA_OBJECTS_PATH", "INFODIR", "INFOPATH", "LDPATH",
+    "ADA_INCLUDE_PATH", "ADA_OBJECTS_PATH", "INFODIR", "INFOPATH", "LDPATH",
     "MANPATH", "PATH", "PYTHONPATH", "PKG_CONFIG_PATH", "ROOTPATH"
 ])
 
@@ -680,15 +677,6 @@ class GenerateTriggers:
             elif 'unmerge-backup' in self.domain.features:
                 yield triggers.SavePkgUnmerging(target_repo=target_repo)
 
-        if 'save-deb' in self.domain.features:
-            path = self.opts.get("DEB_REPO_ROOT", None)
-            if path is None:
-                logger.warning("disabling save-deb; DEB_REPO_ROOT is unset")
-            else:
-                yield ospkg.triggers.SaveDeb(
-                    basepath=normpath(path), maintainer=self.opts.get("DEB_MAINAINER", ''),
-                    platform=self.opts.get("DEB_ARCHITECTURE", ""))
-
         if 'splitdebug' in self.domain.features:
             yield triggers.BinaryDebug(mode='split', compress=('compressdebug' in self.domain.features))
         elif 'strip' in self.domain.features or 'nostrip' not in self.domain.features:
